@@ -20,6 +20,7 @@ import (
 	"context"
 	"errors"
 	"fmt"
+	"os"
 	"reflect"
 	"regexp"
 	"sort"
@@ -27,9 +28,9 @@ import (
 
 	pvdr "github.com/fusor/mig-controller/pkg/cloudprovider"
 	migref "github.com/fusor/mig-controller/pkg/reference"
-	velero "github.com/heptio/velero/pkg/apis/velero/v1"
 	appsv1 "github.com/openshift/api/apps/v1"
 	imagev1 "github.com/openshift/api/image/v1"
+	velero "github.com/vmware-tanzu/velero/pkg/apis/velero/v1"
 	kapi "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/resource"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -44,6 +45,7 @@ const (
 
 // MigPlanSpec defines the desired state of MigPlan
 type MigPlanSpec struct {
+	UnhealthyResources
 	PersistentVolumes `json:",inline"`
 	Namespaces        []string              `json:"namespaces,omitempty"`
 	SrcMigClusterRef  *kapi.ObjectReference `json:"srcMigClusterRef,omitempty"`
@@ -206,9 +208,20 @@ func (r *MigPlan) ListMigrations(client k8sclient.Client) ([]*MigMigration, erro
 
 // Registry label for controller-created migration registry resoruces
 const (
-	MigrationRegistryLabel = "migration-registry"
+	MigrationRegistryLabel        = "migration-registry"
+	MigrationRegistryDefaultImage = "registry:2"
+	MigrationRegistryImageEnvVar  = "MIGRATION_REGISTRY_IMAGE"
 )
 
+// Return the image reference for the migration registry (defaults to "registry:2")
+func migRegistryImageRef() string {
+	envImage := os.Getenv(MigrationRegistryImageEnvVar)
+	if envImage == "" {
+		return MigrationRegistryDefaultImage
+	}
+	return envImage
+}
+
 // Build a credentials Secret as desired for the source cluster.
 func (r *MigPlan) BuildRegistrySecret(client k8sclient.Client, storage *MigStorage) (*kapi.Secret, error) {
 	labels := r.GetCorrelationLabels()
@@ -291,11 +304,11 @@ func (r *MigPlan) UpdateRegistryImageStream(imagestream *imagev1.ImageStream) er
 			imagev1.TagReference{
 				Name: "2",
 				Annotations: map[string]string{
-					"openshift.io/imported-from": "registry:2",
+					"openshift.io/imported-from": migRegistryImageRef(),
 				},
 				From: &kapi.ObjectReference{
 					Kind: "DockerImage",
-					Name: "registry:2",
+					Name: migRegistryImageRef(),
 				},
 				Generation:      nil,
 				ImportPolicy:    imagev1.TagImportPolicy{},
@@ -376,7 +389,7 @@ func (r *MigPlan) UpdateRegistryDC(storage *MigStorage, deploymentconfig *appsv1
 			Spec: kapi.PodSpec{
 				Containers: []kapi.Container{
 					kapi.Container{
-						Image: "registry:2",
+						Image: migRegistryImageRef(),
 						Name:  "registry",
 						Ports: []kapi.ContainerPort{
 							kapi.ContainerPort{
