@@ -15,7 +15,7 @@ package remotewatcher
 
 import (
 	"github.com/fusor/mig-controller/pkg/logging"
-	velerov1 "github.com/heptio/velero/pkg/apis/velero/v1"
+	velerov1 "github.com/vmware-tanzu/velero/pkg/apis/velero/v1"
 	kapi "k8s.io/api/core/v1"
 	storageapi "k8s.io/api/storage/v1"
 	"k8s.io/apimachinery/pkg/runtime"
